from setuptools import setup

setup(name='triop',
      version='1.112',
      description='Gaussian distributions',
      packages=['triop'],
      author = 'Vishesh Jain',
      
      zip_safe=False)
